"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ControllerMui = ControllerMui;
exports.createUseCustomParsedFormFromSchemaUnsafe = createUseCustomParsedFormFromSchemaUnsafe;
exports.createUseForm = createUseForm;
exports.createUseParsedFormFromSchema = createUseParsedFormFromSchema;
exports.createUseParsedFormUnsafe = createUseParsedFormUnsafe;
exports.useControllerMui = useControllerMui;
exports.validateBetweenMidnightAndEndOfDay = validateBetweenMidnightAndEndOfDay;
var tsplus_module_1 = _interopRequireWildcard(require("@effect-ts-app/boilerplate-prelude"));
var tsplus_module_2 = _interopRequireWildcard(require("@fp-ts/data/Option"));
var tsplus_module_3 = _interopRequireWildcard(require("@fp-ts/data/Either"));
var _schema = require("@effect-ts-app/boilerplate-prelude/schema");
var _schema2 = require("@effect-ts-app/schema");
var _react = require("react");
var _reactHookForm = require("react-hook-form");
var _reactIntl = require("react-intl");
var _utils = require("./utils.cjs");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* eslint-disable @typescript-eslint/no-explicit-any */
// TODO: Type the return values of the functions preferably with interfaces!

function useControllerMui(props) {
  const [getFieldMetadata, getMetadata, getRegisterMeta] = useGetMeta(props.control.props);
  const r = (0, _reactHookForm.useController)({
    ...props,
    rules: {
      ...getFieldMetadata(props.name),
      ...props.rules
    }
  });
  const {
    field,
    fieldState: {
      error
    }
  } = r;
  const fieldOnChange = field.onChange;
  const {
    metadata,
    metadataMui,
    onChange,
    transform
  } = (0, _react.useMemo)(() => {
    const getMetadataMui = name => {
      return {
        ...getMetadata(name),
        error: !!error,
        helperText: error?.message
      };
    };
    const {
      transform
    } = getRegisterMeta(props.name);
    const onChange = evt => fieldOnChange(transform.output(getControllerValue(evt)));
    return {
      metadata: getMetadata(props.name),
      metadataMui: getMetadataMui(props.name),
      onChange,
      transform
    };
  }, [getRegisterMeta, props.name, fieldOnChange, getMetadata, error]);
  const {
    ref,
    ...restField
  } = field;
  const value = transform ? transform.input(field.value) : field.value;
  return {
    ...r,
    field: {
      ...field,
      onChange,
      value,
      ...metadata
    },
    fieldMui: {
      innerRef: ref,
      ...restField,
      onChange,
      value,
      ...metadataMui
    }
  };
}
const isCheckBoxInput = element => element.type === "checkbox";
const isDateObject = data => data instanceof Date;
const isNullOrUndefined = value => value == null;
const isObjectType = value => typeof value === "object";
const isObject = value => !isNullOrUndefined(value) && !Array.isArray(value) && isObjectType(value) && !isDateObject(value);
function getControllerValue(event) {
  return isObject(event) && event.target ? isCheckBoxInput(event.target) ? event.target.checked : event.target.value : event;
}
// to apply the metadata also to the field
function ControllerMui(props) {
  return props.render(useControllerMui(props));
}
function getFormMetadata(intl, p) {
  const {
    maxLength,
    minLength,
    required
  } = (0, _schema.getMetadataFromSchemaOrProp)(p);
  return {
    minLength: minLength ? {
      value: minLength,
      message: intl.formatMessage({
        defaultMessage: "The value must be at least {minLength} characters long",
        id: "JxYRlM",
        description: "Default form validation error: min characters"
      }, {
        minLength
      })
    } : undefined,
    maxLength: maxLength ? {
      value: maxLength,
      message: intl.formatMessage({
        defaultMessage: "Only a maximum of {maxLength} characters is allowed",
        id: "4+pPNW",
        description: "Default form validation error: max characters"
      }, {
        maxLength
      })
    } : undefined,
    required: required ? {
      value: required,
      message: intl.formatMessage({
        defaultMessage: "This field can not be empty",
        id: "Vfrho4",
        description: "Default form validation error: required field"
      })
    } : undefined
  };
}
function createUseParsedFormFromSchema(self) {
  return createUseParsedFormUnsafe(self.Api.props)((0, _schema2.EParserFor)(self));
}
/**
 * @unsafe - because the `Shape` has no relation to `Props`
 * This is used to adapt forms to tagged unions.
 * It would be better to make first class support for that instead.
 */
function createUseCustomParsedFormFromSchemaUnsafe(input, target) {
  return createUseParsedFormUnsafe(input.Api.props)(_schema2.Parser.for(target));
}
/**
 * @unsafe - because the `Shape` has no relation to `Props`
 * This is used to adapt forms to tagged unions.
 * It would be better to make first class support for that instead.
 */
function createUseParsedFormUnsafe(props) {
  // We support a separate Parser so that the form may provide at-least, or over-provide.
  // TODO: Encoded should extend Shape (provide at least, or over provide)
  return parser => {
    const parse = parser["|>"](_schema2.unsafe);
    return _ => {
      const originalForm_ = createUseForm(props);
      const form = originalForm_(_);
      return {
        ...form,
        handleSubmit: (onValid, onInvalid, preValidate) => {
          const hs = form.handleSubmit;
          const h = hs(async (_v, e) => {
            if (preValidate && !preValidate()) {
              return;
            }
            const parsed = parse(_v);
            return await onValid(parsed, e);
          }, onInvalid);
          return (
          // eslint-disable-next-line @typescript-eslint/ban-types
          e) => h(e);
        }
      };
    };
  };
}
function createUseForm(props) {
  return function useFormInternal(_) {
    const r = (0, _reactHookForm.useForm)(_);
    const [register, getFieldMetadata, getMetadata] = useRegister(r.register, props);
    const {
      errors
    } = r.formState;
    const control = (0, _react.useMemo)(() => ({
      ...r.control,
      props
    }), [r.control]);
    const getMetadataMui = (0, _react.useCallback)(name => {
      const error = name.split(".").reduce((prev, cur) => prev ? prev[cur] : undefined, errors);
      return {
        ...getMetadata(name),
        error: !!error,
        helperText: error?.message
      };
    }, [getMetadata, errors]);
    const registerMui = (0, _react.useCallback)((name, options) => {
      const propOrSchema = getPropOrSchemaFromPath({
        props
      }, name);
      const {
        transform,
        ...customReg
      } = (0, _schema.getRegisterFromSchemaOrProp)(propOrSchema);
      // TODO: check and filter options for custom setValueAs / valueAsNumber / valueAsDate
      const setValueAs = value => transform.output(value);
      const reg = register(name, {
        ...customReg,
        setValueAs,
        ...options
      });
      const rootProps = getMetadataMui(name);
      return {
        ...rootProps,
        inputProps: reg
        // required:
        //   options && "required" in options ? !!options.required : rootProps.required,
      };
    }, [getMetadataMui, register]);
    return {
      ...r,
      control,
      register,
      registerMui,
      getFieldMetadata,
      getMetadata,
      getMetadataMui
    };
  };
}
function isNumber(a) {
  const parsed = parseInt(a);
  const isNumber = parsed === 0 || !!parsed;
  return isNumber;
}
// We have to differentiate between Prop and raw schema.
function getPropOrSchemaFromPath(current, name) {
  const path = name.split(".");
  // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
  const last = path[path.length - 1];
  const left = path.slice(0, path.length - 1);
  // obj; a.b.c
  // array = a.0.b.c
  for (const p of left) {
    if (isNumber(p)) {
      current = current.self; // returns a schema, not a prop
    } else {
      current = current.props[p]._schema.Api;
    }
  }
  if (isNumber(last)) {
    current = current.self; // returns a schema, not a prop
  } else {
    current = current.props[last];
  }
  return current;
}
function useGetMeta(props) {
  const intl = (0, _reactIntl.useIntl)();
  const {
    getFieldMetadata,
    getMetadata,
    getRegisterMeta
  } = (0, _react.useMemo)(() => {
    const getMetadata = name => {
      const propOrSchema = getPropOrSchemaFromPath({
        props
      }, name);
      return (0, _schema.getMetadataFromSchemaOrProp)(propOrSchema);
    };
    const getFieldMetadata = (name, additionalValidation) => {
      const propOrSchema = getPropOrSchemaFromPath({
        props
      }, name);
      const meta = (0, _schema.getRegisterFromSchemaOrProp)(propOrSchema);
      const schema = (0, _schema.isSchema)(propOrSchema) ? propOrSchema : propOrSchema._schema;
      const parse = tsplus_module_1.Schema.Parser.for(schema);
      const validate = i => parse(meta.transform.output(i))["|>"](_schema2.These.result)["|>"](r => tsplus_module_3.match(() => intl.formatMessage({
        defaultMessage: "The entered value is not a valid {modelName}",
        id: "/do4+3",
        description: "Default form validation error: model invalid"
      }, {
        modelName: (0, _utils.capitalize)(name.toString())
      }), ([_, optErr]) => tsplus_module_2.isSome(optErr) ? intl.formatMessage({
        defaultMessage: "The entered value is not a valid {modelName}",
        id: "/do4+3",
        description: "Default form validation error: model invalid"
      }, {
        modelName: (0, _utils.capitalize)(name.toString())
      }) : undefined)(r) ?? (additionalValidation ? additionalValidation(i) : undefined));
      return {
        validate,
        ...getFormMetadata(intl, propOrSchema)
      };
    };
    const getRegisterMeta = name => {
      const propOrSchema = getPropOrSchemaFromPath({
        props
      }, name);
      const meta = (0, _schema.getRegisterFromSchemaOrProp)(propOrSchema);
      return meta;
    };
    return {
      getMetadata,
      getRegisterMeta,
      getFieldMetadata
    };
  }, [props, intl]);
  return [getFieldMetadata, getMetadata, getRegisterMeta];
}
function useRegister(register_, props) {
  const [getFieldMetadata, getMetadata] = useGetMeta(props);
  const register = (0, _react.useCallback)((name, options) => register_(name, {
    ...getFieldMetadata(name),
    ...options
  }), [register_, getFieldMetadata]);
  return [register, getFieldMetadata, getMetadata];
}
function validateBetweenMidnightAndEndOfDay(minDate, maxDate) {
  return d => !(0, _utils.isBetweenMidnightAndEndOfDay)(minDate, maxDate)(d) ? "Not within expected date range" : undefined;
}
//# sourceMappingURL=form.cjs.map