import { Schema } from "@effect-ts-app/boilerplate-prelude";
import { type AnyError, type ConstructorFromProperties, type EncodedFromProperties, Parser, type PropertyRecord, type ShapeFromProperties } from "@effect-ts-app/schema";
import type { BaseSyntheticEvent } from "react";
import type { Control, ControllerFieldState, ControllerProps, ControllerRenderProps, FieldPath, FieldPathValue, FieldValues, PathValue, RegisterOptions, SubmitErrorHandler, UnpackNestedValue, UseControllerProps, UseFormProps, UseFormRegister, UseFormStateReturn, Validate } from "react-hook-form";
export interface ControlMui<Props extends Schema.PropertyRecord, TFieldValues extends FieldValues = FieldValues, TContext extends object = object> extends Control<TFieldValues, TContext> {
    props: Props;
}
export interface ControllerMuiProps<Props extends Schema.PropertyRecord, TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> extends Omit<UseControllerProps<TFieldValues, TName>, "control"> {
    control: ControlMui<Props, TFieldValues>;
}
export declare function useControllerMui<Props extends Schema.PropertyRecord, TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: ControllerMuiProps<Props, TFieldValues, TName>): {
    field: {
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
        onChange: (evt: any) => void;
        value: PathValue<TFieldValues, TName>;
        onBlur: import("react-hook-form").Noop;
        name: TName;
        ref: import("react-hook-form").RefCallBack;
    };
    fieldMui: {
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
        onChange: (evt: any) => void;
        value: PathValue<TFieldValues, TName>;
        onBlur: import("react-hook-form").Noop;
        name: TName;
        innerRef: import("react-hook-form").RefCallBack;
    };
    formState: UseFormStateReturn<TFieldValues>;
    fieldState: ControllerFieldState;
};
interface Metadata {
    minLength: number | undefined;
    maxLength: number | undefined;
    required: boolean;
}
export interface FieldMui<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> extends Omit<ControllerRenderProps<TFieldValues, TName>, "ref">, Metadata {
    innerRef: ControllerRenderProps<TFieldValues, TName>["ref"];
    onChange: (evtOrValue: {
        target: {
            value: UnpackNestedValue<FieldPathValue<TFieldValues, TName>>;
        };
    } | UnpackNestedValue<FieldPathValue<TFieldValues, TName>>) => void;
    error: boolean;
    helperText: string | undefined;
}
export interface MuiRenderProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> {
    field: ControllerRenderProps<TFieldValues, TName> & Metadata;
    fieldState: ControllerFieldState;
    formState: UseFormStateReturn<TFieldValues>;
    fieldMui: FieldMui<TFieldValues, TName>;
}
export interface MuiProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, Props extends Schema.PropertyRecord = Schema.PropertyRecord> extends Omit<ControllerProps<TFieldValues, TName>, "control" | "render"> {
    control: ControlMui<Props, TFieldValues>;
    render: (_: MuiRenderProps<TFieldValues, TName>) => React.ReactElement;
}
export declare function ControllerMui<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, Props extends Schema.PropertyRecord = Schema.PropertyRecord>(props: MuiProps<TFieldValues, TName, Props>): import("react").ReactElement<any, string | import("react").JSXElementConstructor<any>>;
export interface Val<T> {
    value: T;
    message: string;
}
export interface FormMetadata {
    minLength: Val<number> | undefined;
    maxLength: Val<number> | undefined;
    required: Val<boolean> | undefined;
}
export type SchemaProperties<Props extends PropertyRecord> = Schema.Schema<unknown, ShapeFromProperties<Props>, ConstructorFromProperties<Props>, EncodedFromProperties<Props>, {
    props: Props;
}>;
export declare function createUseParsedFormFromSchema<Props extends PropertyRecord>(self: SchemaProperties<Props>): <TContext extends object = object>(_?: (Omit<Partial<{
    mode: keyof import("react-hook-form").ValidationMode;
    reValidateMode: "onChange" | "onBlur" | "onSubmit";
    defaultValues: import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    resolver: import("react-hook-form").Resolver<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TContext>;
    context: TContext;
    shouldFocusError: boolean;
    shouldUnregister: boolean;
    shouldUseNativeValidation: boolean;
    criteriaMode: import("react-hook-form").CriteriaMode;
    delayError: number;
}>, "defaultValues"> & {
    defaultValues: import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>;
}) | undefined) => {
    handleSubmit: (onValid: (data: import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k_1 in keyof Props]: Props[k_1] extends import("@effect-ts-app/schema").AnyProperty ? Props[k_1]["_optional"] extends "optional" ? { readonly [h_2 in k_1]?: import("@effect-ts-app/schema").ParsedShapeOf<Props[k_1]["_schema"]> | undefined; } : { readonly [h_3 in k_1]: import("@effect-ts-app/schema").ParsedShapeOf<Props[k_1]["_schema"]>; } : never; }[keyof Props]>>, event?: BaseSyntheticEvent<object, any, any> | undefined) => Promise<unknown>, onInvalid?: SubmitErrorHandler<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>> | undefined, preValidate?: (() => boolean) | undefined) => (e?: BaseSyntheticEvent<object, any, any> | undefined) => Promise<void>;
    control: {
        props: Props;
        _subjects: import("react-hook-form").Subjects<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _removeUnmounted: import("react-hook-form").Noop;
        _focusError: import("react-hook-form").Noop;
        _names: import("react-hook-form").Names;
        _stateFlags: {
            mount: boolean;
            action: boolean;
            watch: boolean;
        };
        _options: Partial<{
            mode: keyof import("react-hook-form").ValidationMode;
            reValidateMode: "onChange" | "onBlur" | "onSubmit";
            defaultValues: import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
            resolver: import("react-hook-form").Resolver<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TContext>;
            context: TContext;
            shouldFocusError: boolean;
            shouldUnregister: boolean;
            shouldUseNativeValidation: boolean;
            criteriaMode: import("react-hook-form").CriteriaMode;
            delayError: number;
        }>;
        _getDirty: import("react-hook-form").GetIsDirty;
        _formState: import("react-hook-form").FormState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _updateValid: import("react-hook-form").Noop;
        _fields: Partial<Record<string, import("react-hook-form").Field>>;
        _formValues: FieldValues;
        _proxyFormState: import("react-hook-form").ReadFormState;
        _defaultValues: Partial<import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>;
        _getWatch: import("react-hook-form").WatchInternal<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _updateFieldArray: import("react-hook-form").BatchFieldArrayUpdate;
        _getFieldArray: <TFieldArrayValues>(name: string) => Partial<TFieldArrayValues>[];
        _executeSchema: (names: string[]) => Promise<{
            errors: Partial<import("react-hook-form").FieldErrorsImpl<{
                [x: string]: any;
            }>>;
        }>;
        register: UseFormRegister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        unregister: import("react-hook-form").UseFormUnregister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        getFieldState: import("react-hook-form").UseFormGetFieldState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    };
    register: <TFieldName extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>> | Record<string, Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => import("react-hook-form").UseFormRegisterReturn<TFieldName>;
    registerMui: <TFieldName_1 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_1, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>> | Record<string, Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => {
        inputProps: import("react-hook-form").UseFormRegisterReturn<TFieldName_1>;
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getFieldMetadata: <TFieldName_2 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_2, additionalValidation?: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_2>> | undefined) => {
        minLength: Val<number> | undefined;
        maxLength: Val<number> | undefined;
        required: Val<boolean> | undefined;
        validate: (i: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_2>) => import("react-hook-form").ValidateResult | Promise<import("react-hook-form").ValidateResult>;
    };
    getMetadata: <TFieldName_3 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_3) => {
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getMetadataMui: <TFieldName_4 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_4) => {
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    watch: import("react-hook-form").UseFormWatch<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    getValues: import("react-hook-form").UseFormGetValues<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    getFieldState: import("react-hook-form").UseFormGetFieldState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setError: import("react-hook-form").UseFormSetError<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    clearErrors: import("react-hook-form").UseFormClearErrors<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setValue: import("react-hook-form").UseFormSetValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    trigger: import("react-hook-form").UseFormTrigger<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    formState: import("react-hook-form").FormState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    resetField: import("react-hook-form").UseFormResetField<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    reset: import("react-hook-form").UseFormReset<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    unregister: import("react-hook-form").UseFormUnregister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setFocus: import("react-hook-form").UseFormSetFocus<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
};
/**
 * @unsafe - because the `Shape` has no relation to `Props`
 * This is used to adapt forms to tagged unions.
 * It would be better to make first class support for that instead.
 */
export declare function createUseCustomParsedFormFromSchemaUnsafe<Props extends PropertyRecord, ParsedShape>(input: SchemaProperties<Props>, target: Schema.Schema<unknown, ParsedShape, any, any, any>): <TContext extends object = object>(_?: (Omit<Partial<{
    mode: keyof import("react-hook-form").ValidationMode;
    reValidateMode: "onChange" | "onBlur" | "onSubmit";
    defaultValues: import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    resolver: import("react-hook-form").Resolver<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TContext>;
    context: TContext;
    shouldFocusError: boolean;
    shouldUnregister: boolean;
    shouldUseNativeValidation: boolean;
    criteriaMode: import("react-hook-form").CriteriaMode;
    delayError: number;
}>, "defaultValues"> & {
    defaultValues: import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>;
}) | undefined) => {
    handleSubmit: (onValid: (data: ParsedShape, event?: BaseSyntheticEvent<object, any, any> | undefined) => Promise<unknown>, onInvalid?: SubmitErrorHandler<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>> | undefined, preValidate?: (() => boolean) | undefined) => (e?: BaseSyntheticEvent<object, any, any> | undefined) => Promise<void>;
    control: {
        props: Props;
        _subjects: import("react-hook-form").Subjects<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _removeUnmounted: import("react-hook-form").Noop;
        _focusError: import("react-hook-form").Noop;
        _names: import("react-hook-form").Names;
        _stateFlags: {
            mount: boolean;
            action: boolean;
            watch: boolean;
        };
        _options: Partial<{
            mode: keyof import("react-hook-form").ValidationMode;
            reValidateMode: "onChange" | "onBlur" | "onSubmit";
            defaultValues: import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
            resolver: import("react-hook-form").Resolver<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TContext>;
            context: TContext;
            shouldFocusError: boolean;
            shouldUnregister: boolean;
            shouldUseNativeValidation: boolean;
            criteriaMode: import("react-hook-form").CriteriaMode;
            delayError: number;
        }>;
        _getDirty: import("react-hook-form").GetIsDirty;
        _formState: import("react-hook-form").FormState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _updateValid: import("react-hook-form").Noop;
        _fields: Partial<Record<string, import("react-hook-form").Field>>;
        _formValues: FieldValues;
        _proxyFormState: import("react-hook-form").ReadFormState;
        _defaultValues: Partial<import("react-hook-form").DeepPartial<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>;
        _getWatch: import("react-hook-form").WatchInternal<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        _updateFieldArray: import("react-hook-form").BatchFieldArrayUpdate;
        _getFieldArray: <TFieldArrayValues>(name: string) => Partial<TFieldArrayValues>[];
        _executeSchema: (names: string[]) => Promise<{
            errors: Partial<import("react-hook-form").FieldErrorsImpl<{
                [x: string]: any;
            }>>;
        }>;
        register: UseFormRegister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        unregister: import("react-hook-form").UseFormUnregister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
        getFieldState: import("react-hook-form").UseFormGetFieldState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    };
    register: <TFieldName extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>> | Record<string, Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => import("react-hook-form").UseFormRegisterReturn<TFieldName>;
    registerMui: <TFieldName_1 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_1, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>> | Record<string, Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_1>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => {
        inputProps: import("react-hook-form").UseFormRegisterReturn<TFieldName_1>;
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getFieldMetadata: <TFieldName_2 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_2, additionalValidation?: Validate<PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_2>> | undefined) => {
        minLength: Val<number> | undefined;
        maxLength: Val<number> | undefined;
        required: Val<boolean> | undefined;
        validate: (i: PathValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>, TFieldName_2>) => import("react-hook-form").ValidateResult | Promise<import("react-hook-form").ValidateResult>;
    };
    getMetadata: <TFieldName_3 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_3) => {
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getMetadataMui: <TFieldName_4 extends import("react-hook-form").Path<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>>(name: TFieldName_4) => {
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    watch: import("react-hook-form").UseFormWatch<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    getValues: import("react-hook-form").UseFormGetValues<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    getFieldState: import("react-hook-form").UseFormGetFieldState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setError: import("react-hook-form").UseFormSetError<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    clearErrors: import("react-hook-form").UseFormClearErrors<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setValue: import("react-hook-form").UseFormSetValue<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    trigger: import("react-hook-form").UseFormTrigger<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    formState: import("react-hook-form").FormState<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    resetField: import("react-hook-form").UseFormResetField<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    reset: import("react-hook-form").UseFormReset<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    unregister: import("react-hook-form").UseFormUnregister<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
    setFocus: import("react-hook-form").UseFormSetFocus<import("@effect-ts/system/Utils").ComputeFlat<import("@effect-ts/system/Utils").UnionToIntersection<{ [k in keyof Props]: Props[k] extends import("@effect-ts-app/schema").AnyProperty ? Props[k]["_optional"] extends "optional" ? { readonly [h in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]?: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]> | undefined; } : { readonly [h_1 in Props[k]["_as"] extends import("@fp-ts/data/Option").Some<any> ? Props[k]["_as"]["value"] : k]: import("@effect-ts-app/schema").EncodedOf<Props[k]["_schema"]>; } : never; }[keyof Props]>>>;
};
/**
 * @unsafe - because the `Shape` has no relation to `Props`
 * This is used to adapt forms to tagged unions.
 * It would be better to make first class support for that instead.
 */
export declare function createUseParsedFormUnsafe<Props extends PropertyRecord>(props: Props): <Shape, ParserE extends AnyError>(parser: Parser.Parser<EncodedFromProperties<Props>, ParserE, Shape>) => <TContext extends object = object>(_?: (Omit<Partial<{
    mode: keyof import("react-hook-form").ValidationMode;
    reValidateMode: "onChange" | "onBlur" | "onSubmit";
    defaultValues: import("react-hook-form").DeepPartial<EncodedFromProperties<Props>>;
    resolver: import("react-hook-form").Resolver<EncodedFromProperties<Props>, TContext>;
    context: TContext;
    shouldFocusError: boolean;
    shouldUnregister: boolean;
    shouldUseNativeValidation: boolean;
    criteriaMode: import("react-hook-form").CriteriaMode;
    delayError: number;
}>, "defaultValues"> & {
    defaultValues: EncodedFromProperties<Props>;
}) | undefined) => {
    handleSubmit: (onValid: (data: Shape, event?: React.BaseSyntheticEvent) => Promise<unknown>, onInvalid?: SubmitErrorHandler<EncodedFromProperties<Props>> | undefined, preValidate?: () => boolean) => (e?: BaseSyntheticEvent<object, any, any> | undefined) => Promise<void>;
    control: {
        props: Props;
        _subjects: import("react-hook-form").Subjects<EncodedFromProperties<Props>>;
        _removeUnmounted: import("react-hook-form").Noop;
        _focusError: import("react-hook-form").Noop;
        _names: import("react-hook-form").Names;
        _stateFlags: {
            mount: boolean;
            action: boolean;
            watch: boolean;
        };
        _options: Partial<{
            mode: keyof import("react-hook-form").ValidationMode;
            reValidateMode: "onChange" | "onBlur" | "onSubmit";
            defaultValues: import("react-hook-form").DeepPartial<EncodedFromProperties<Props>>;
            resolver: import("react-hook-form").Resolver<EncodedFromProperties<Props>, TContext>;
            context: TContext;
            shouldFocusError: boolean;
            shouldUnregister: boolean;
            shouldUseNativeValidation: boolean;
            criteriaMode: import("react-hook-form").CriteriaMode;
            delayError: number;
        }>;
        _getDirty: import("react-hook-form").GetIsDirty;
        _formState: import("react-hook-form").FormState<EncodedFromProperties<Props>>;
        _updateValid: import("react-hook-form").Noop;
        _fields: Partial<Record<string, import("react-hook-form").Field>>;
        _formValues: FieldValues;
        _proxyFormState: import("react-hook-form").ReadFormState;
        _defaultValues: Partial<import("react-hook-form").DeepPartial<EncodedFromProperties<Props>>>;
        _getWatch: import("react-hook-form").WatchInternal<EncodedFromProperties<Props>>;
        _updateFieldArray: import("react-hook-form").BatchFieldArrayUpdate;
        _getFieldArray: <TFieldArrayValues>(name: string) => Partial<TFieldArrayValues>[];
        _executeSchema: (names: string[]) => Promise<{
            errors: Partial<import("react-hook-form").FieldErrorsImpl<{
                [x: string]: any;
            }>>;
        }>;
        register: UseFormRegister<EncodedFromProperties<Props>>;
        unregister: import("react-hook-form").UseFormUnregister<EncodedFromProperties<Props>>;
        getFieldState: import("react-hook-form").UseFormGetFieldState<EncodedFromProperties<Props>>;
    };
    register: <TFieldName extends import("react-hook-form").Path<EncodedFromProperties<Props>>>(name: TFieldName, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<EncodedFromProperties<Props>, TFieldName>> | Record<string, Validate<PathValue<EncodedFromProperties<Props>, TFieldName>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<EncodedFromProperties<Props>, TFieldName>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => import("react-hook-form").UseFormRegisterReturn<TFieldName>;
    registerMui: <TFieldName_1 extends import("react-hook-form").Path<EncodedFromProperties<Props>>>(name: TFieldName_1, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<EncodedFromProperties<Props>, TFieldName_1>> | Record<string, Validate<PathValue<EncodedFromProperties<Props>, TFieldName_1>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<EncodedFromProperties<Props>, TFieldName_1>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => {
        inputProps: import("react-hook-form").UseFormRegisterReturn<TFieldName_1>;
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getFieldMetadata: <TFieldName_2 extends import("react-hook-form").Path<EncodedFromProperties<Props>>>(name: TFieldName_2, additionalValidation?: Validate<PathValue<EncodedFromProperties<Props>, TFieldName_2>> | undefined) => {
        minLength: Val<number> | undefined;
        maxLength: Val<number> | undefined;
        required: Val<boolean> | undefined;
        validate: (i: PathValue<EncodedFromProperties<Props>, TFieldName_2>) => import("react-hook-form").ValidateResult | Promise<import("react-hook-form").ValidateResult>;
    };
    getMetadata: <TFieldName_3 extends import("react-hook-form").Path<EncodedFromProperties<Props>>>(name: TFieldName_3) => {
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getMetadataMui: <TFieldName_4 extends import("react-hook-form").Path<EncodedFromProperties<Props>>>(name: TFieldName_4) => {
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    watch: import("react-hook-form").UseFormWatch<EncodedFromProperties<Props>>;
    getValues: import("react-hook-form").UseFormGetValues<EncodedFromProperties<Props>>;
    getFieldState: import("react-hook-form").UseFormGetFieldState<EncodedFromProperties<Props>>;
    setError: import("react-hook-form").UseFormSetError<EncodedFromProperties<Props>>;
    clearErrors: import("react-hook-form").UseFormClearErrors<EncodedFromProperties<Props>>;
    setValue: import("react-hook-form").UseFormSetValue<EncodedFromProperties<Props>>;
    trigger: import("react-hook-form").UseFormTrigger<EncodedFromProperties<Props>>;
    formState: import("react-hook-form").FormState<EncodedFromProperties<Props>>;
    resetField: import("react-hook-form").UseFormResetField<EncodedFromProperties<Props>>;
    reset: import("react-hook-form").UseFormReset<EncodedFromProperties<Props>>;
    unregister: import("react-hook-form").UseFormUnregister<EncodedFromProperties<Props>>;
    setFocus: import("react-hook-form").UseFormSetFocus<EncodedFromProperties<Props>>;
};
export declare function createUseForm<Props extends PropertyRecord = PropertyRecord>(props: Props): <TFieldValues extends EncodedFromProperties<Props>, TContext extends object = object>(_?: Partial<{
    mode: keyof import("react-hook-form").ValidationMode;
    reValidateMode: "onChange" | "onBlur" | "onSubmit";
    defaultValues: import("react-hook-form").DeepPartial<TFieldValues>;
    resolver: import("react-hook-form").Resolver<TFieldValues, TContext>;
    context: TContext;
    shouldFocusError: boolean;
    shouldUnregister: boolean;
    shouldUseNativeValidation: boolean;
    criteriaMode: import("react-hook-form").CriteriaMode;
    delayError: number;
}> | undefined) => {
    control: {
        props: Props;
        _subjects: import("react-hook-form").Subjects<TFieldValues>;
        _removeUnmounted: import("react-hook-form").Noop;
        _focusError: import("react-hook-form").Noop;
        _names: import("react-hook-form").Names;
        _stateFlags: {
            mount: boolean;
            action: boolean;
            watch: boolean;
        };
        _options: Partial<{
            mode: keyof import("react-hook-form").ValidationMode;
            reValidateMode: "onChange" | "onBlur" | "onSubmit";
            defaultValues: import("react-hook-form").DeepPartial<TFieldValues>;
            resolver: import("react-hook-form").Resolver<TFieldValues, TContext>;
            context: TContext;
            shouldFocusError: boolean;
            shouldUnregister: boolean;
            shouldUseNativeValidation: boolean;
            criteriaMode: import("react-hook-form").CriteriaMode;
            delayError: number;
        }>;
        _getDirty: import("react-hook-form").GetIsDirty;
        _formState: import("react-hook-form").FormState<TFieldValues>;
        _updateValid: import("react-hook-form").Noop;
        _fields: Partial<Record<string, import("react-hook-form").Field>>;
        _formValues: FieldValues;
        _proxyFormState: import("react-hook-form").ReadFormState;
        _defaultValues: Partial<import("react-hook-form").DeepPartial<TFieldValues>>;
        _getWatch: import("react-hook-form").WatchInternal<TFieldValues>;
        _updateFieldArray: import("react-hook-form").BatchFieldArrayUpdate;
        _getFieldArray: <TFieldArrayValues>(name: string) => Partial<TFieldArrayValues>[];
        _executeSchema: (names: string[]) => Promise<{
            errors: Partial<import("react-hook-form").FieldErrorsImpl<{
                [x: string]: any;
            }>>;
        }>;
        register: UseFormRegister<TFieldValues>;
        unregister: import("react-hook-form").UseFormUnregister<TFieldValues>;
        getFieldState: import("react-hook-form").UseFormGetFieldState<TFieldValues>;
    };
    register: <TFieldName extends import("react-hook-form").Path<TFieldValues>>(name: TFieldName, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<TFieldValues, TFieldName>> | Record<string, Validate<PathValue<TFieldValues, TFieldName>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<TFieldValues, TFieldName>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => import("react-hook-form").UseFormRegisterReturn<TFieldName>;
    registerMui: <TFieldName_1 extends FieldPath<TFieldValues>>(name: TFieldName_1, options?: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: Validate<PathValue<TFieldValues, TFieldName_1>> | Record<string, Validate<PathValue<TFieldValues, TFieldName_1>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: PathValue<TFieldValues, TFieldName_1>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }> | undefined) => {
        inputProps: import("react-hook-form").UseFormRegisterReturn<TFieldName_1>;
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getFieldMetadata: <TFieldName_2 extends import("react-hook-form").Path<TFieldValues>>(name: TFieldName_2, additionalValidation?: Validate<PathValue<TFieldValues, TFieldName_2>> | undefined) => {
        minLength: Val<number> | undefined;
        maxLength: Val<number> | undefined;
        required: Val<boolean> | undefined;
        validate: (i: PathValue<TFieldValues, TFieldName_2>) => import("react-hook-form").ValidateResult | Promise<import("react-hook-form").ValidateResult>;
    };
    getMetadata: <TFieldName_3 extends import("react-hook-form").Path<TFieldValues>>(name: TFieldName_3) => {
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    getMetadataMui: <TFieldName_4 extends FieldPath<TFieldValues>>(name: TFieldName_4) => {
        error: boolean;
        helperText: string | undefined;
        minLength: number | undefined;
        maxLength: number | undefined;
        required: boolean;
    };
    watch: import("react-hook-form").UseFormWatch<TFieldValues>;
    getValues: import("react-hook-form").UseFormGetValues<TFieldValues>;
    getFieldState: import("react-hook-form").UseFormGetFieldState<TFieldValues>;
    setError: import("react-hook-form").UseFormSetError<TFieldValues>;
    clearErrors: import("react-hook-form").UseFormClearErrors<TFieldValues>;
    setValue: import("react-hook-form").UseFormSetValue<TFieldValues>;
    trigger: import("react-hook-form").UseFormTrigger<TFieldValues>;
    formState: import("react-hook-form").FormState<TFieldValues>;
    resetField: import("react-hook-form").UseFormResetField<TFieldValues>;
    reset: import("react-hook-form").UseFormReset<TFieldValues>;
    handleSubmit: import("react-hook-form").UseFormHandleSubmit<TFieldValues>;
    unregister: import("react-hook-form").UseFormUnregister<TFieldValues>;
    setFocus: import("react-hook-form").UseFormSetFocus<TFieldValues>;
};
export declare function validateBetweenMidnightAndEndOfDay(minDate?: Date, maxDate?: Date): (d: Date) => "Not within expected date range" | undefined;
export {};
//# sourceMappingURL=form.d.ts.map